==> migrate-2.1.3.src.tar.gz: migrate-2.1.3/src/options.h <==
#ifndef OPTIONS_INCLUDE
#define OPTIONS_INCLUDE
/*------------------------------------------------------
 Maximum likelihood estimation 
 of migration rate  and effectice population size
 using a Metropolis-Hastings Monte Carlo algorithm                            
 -------------------------------------------------------                        
 O P T I O N S   R O U T I N E S 
 
 creates options structures,
 reads options from parmfile if present
 set first parameter for mcmc run,
 prints options,
 and finally helps to destroy itself.
                                                                                                               
 Peter Beerli 1996, Seattle
 beerli@csit.fsu.edu
 
Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
Copyright 2003-2004 Peter Beerli, Tallahassee FL
 
$Id: options.h 220 2006-01-10 19:00:59Z beerli $
-------------------------------------------------------*/

#include "migration.h"

extern void create_options (option_fmt ** options);
extern void init_options (option_fmt * options);
//extern void get_options (option_fmt * options);
extern void set_param (world_fmt * world, data_fmt * data,
                           option_fmt * options, long locus);
extern void set_profile_options (option_fmt * options);
extern void print_menu_options (world_fmt * world, option_fmt * options,
                                    data_fmt * data);
extern void print_options (FILE * file, world_fmt * world,
                               option_fmt * options, data_fmt * data);
extern void print_options_nomcmc (FILE * file, option_fmt * options,
                                      world_fmt * world);
extern void decide_plot (worldoption_fmt * options, long chain, long chains,
                             char type);
extern void destroy_options (option_fmt * options);
extern void read_custom_migration (FILE * file, option_fmt * options,
                                       char *value, long customnumpop);
extern void fillup_custm (long len, world_fmt * world, option_fmt * options);
extern void save_parmfile (option_fmt * options);
extern void set_plot (option_fmt * options);
extern void synchronize_param (world_fmt * world, option_fmt * options);
extern void resynchronize_param (world_fmt * world);
extern long save_options_buffer (char **buffer, option_fmt * options);
extern void read_options_master (option_fmt * options);
extern void read_options_worker (char **buffer, option_fmt * options);
extern long scan_connect (char *custm2, long start, long stop, char check);

extern char * show_priormin(char *tmp, prior_fmt *prior, int priortype);
extern char * show_priormean(char *tmp, prior_fmt *prior, int priortype);
extern char * show_priormax(char *tmp, prior_fmt *prior, int priortype);
extern char * show_priordelta(char *tmp, prior_fmt *prior, int priortype);
extern char * show_priorbins(char *tmp, prior_fmt *prior, int priortype);
#endif /*OPTIONS_INCLUDE */

==> migrate-2.3.src.tar.gz: migrate-2.3/src/options.h <==
#ifndef OPTIONS_INCLUDE
#define OPTIONS_INCLUDE
/*------------------------------------------------------
 Maximum likelihood estimation 
 of migration rate  and effectice population size
 using a Metropolis-Hastings Monte Carlo algorithm                            
 -------------------------------------------------------                        
 O P T I O N S   R O U T I N E S 
 
 creates options structures,
 reads options from parmfile if present
 set first parameter for mcmc run,
 prints options,
 and finally helps to destroy itself.
                                                                                                               
 Peter Beerli 1996, Seattle
 beerli@scs.fsu.edu
 
Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
Copyright 2003-2004 Peter Beerli, Tallahassee FL
 
$Id: options.h 729 2007-05-29 19:01:52Z beerli $
-------------------------------------------------------*/

#include "migration.h"

extern void create_options (option_fmt ** options);
extern void init_options (option_fmt * options);
//extern void get_options (option_fmt * options);
extern void set_param (world_fmt * world, data_fmt * data,
                           option_fmt * options, long locus);
extern void set_profile_options (option_fmt * options);
extern void print_menu_options (world_fmt * world, option_fmt * options,
                                    data_fmt * data);
extern void print_options (FILE * file, world_fmt * world,
                               option_fmt * options, data_fmt * data);
extern void print_options_nomcmc (FILE * file, option_fmt * options,
                                      world_fmt * world);
extern void decide_plot (worldoption_fmt * options, long chain, long chains,
                             char type);
extern void destroy_options (option_fmt * options);
extern void read_custom_migration (FILE * file, option_fmt * options,
                                       char *value, long customnumpop);
extern void fillup_custm (long len, world_fmt * world, option_fmt * options);
extern void save_parmfile (option_fmt * options);
extern void set_plot (option_fmt * options);
extern void synchronize_param (world_fmt * world, option_fmt * options);
extern void resynchronize_param (world_fmt * world);
extern long save_options_buffer (char **buffer, option_fmt * options);
extern void set_meanmu(world_fmt * world, option_fmt * options);
extern long save_mu_rates_buffer (char **buffer, option_fmt * options);
extern void read_options_master (option_fmt * options);
extern void read_options_worker (char **buffer, option_fmt * options);
extern long scan_connect (char *custm2, long start, long stop, int check);

extern char * show_priormin(char *tmp, prior_fmt *prior, int priortype);
extern char * show_priormean(char *tmp, prior_fmt *prior, int priortype);
extern char * show_priormax(char *tmp, prior_fmt *prior, int priortype);
extern char * show_priordelta(char *tmp, prior_fmt *prior, int priortype);
extern char * show_priorbins(char *tmp, prior_fmt *prior, int priortype);
#endif /*OPTIONS_INCLUDE */
